@@ -1,11 +1,12 @@
 # Utility functions for the pip accelerator.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: August 12, 2013
+# Last Change: June 29, 2014
 # URL: https://github.com/paylogic/pip-accel
 
 # Standard library modules.
 import os
+import pipes
 import pwd
 import re
 import sys
@@ -14,6 +15,18 @@ import sys
 # pathnames relative to the home directory.
 HOME = pwd.getpwuid(os.getuid()).pw_dir
 
+def run(command, **params):
+    """
+    Format command string with quoted parameters and execute external command.
+
+    :param command: The shell command line to run (a string).
+    :param params: Zero or more keyword arguments to be formatted into the
+                   command line as quoted arguments.
+    :returns: ``True`` if the command succeeds, ``False`` otherwise.
+    """
+    params = dict((k, pipes.quote(v)) for k, v in params.items())
+    return os.system(command.format(**params)) == 0
+
 def expand_user(pathname):
     """
     Variant of :py:func:`os.path.expanduser()` that doesn't use ``$HOME`` but
